@@ -7,45 +7,45 @@ P. Cook in IEEE Transactions on Audio and Speech Processing 2002.
 
 The dataset consists of 1000 audio tracks each 30 seconds long. It
 contains 10 genres, each represented by 100 tracks. The tracks are all
-22050Hz Mono 16-bit audio files in .wav format.
+22050 Hz mono 16-bit audio files in .wav format.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-import os
 import librosa
+import os
 
 from mirdata import download_utils
+from mirdata import jams_utils
+from mirdata import track
 from mirdata import utils
 
 
 DATASET_DIR = "GTZAN-Genre"
 
-DATASET_REMOTE = download_utils.RemoteFileMetadata(
-    filename="genres.tar.gz",
-    url="http://opihi.cs.uvic.ca/sound/genres.tar.gz",
-    checksum="5b3d6dddb579ab49814ab86dba69e7c7",
-    destination_dir="gtzan_genre",
-)
-
+REMOTES = {
+    'all': download_utils.RemoteFileMetadata(
+        filename="genres.tar.gz",
+        url="http://opihi.cs.uvic.ca/sound/genres.tar.gz",
+        checksum="5b3d6dddb579ab49814ab86dba69e7c7",
+        destination_dir="gtzan_genre",
+    )
+}
 
 DATA = utils.LargeData("gtzan_genre_index.json")
 
 
-class Track(object):
-    """GTZAN-Genre track class
+class Track(track.Track):
+    """gtzan_genre Track class
 
     Args:
         track_id (str): track id of the track
-        data_home (str): Local path where the dataset is stored.
-            If `None`, looks for the data in the default directory, `~/mir_datasets/GuitarSet`
+        data_home (str): Local path where the dataset is stored. default=None
+            If `None`, looks for the data in the default directory, `~/mir_datasets`
 
     Attributes:
-        track_id (str): track id
+        audio_path (str): path to the audio file
         genre (str): annotated genre
-        audio_path (str): absolute audio path
+        track_id (str): track id
+
     """
 
     def __init__(self, track_id, data_home=None):
@@ -63,26 +63,47 @@ class Track(object):
         self._track_paths = DATA.index[track_id]
 
         self.genre = track_id.split(".")[0]
+        if self.genre == 'hiphop':
+            self.genre = 'hip-hop'
+
         self.audio_path = os.path.join(self._data_home, self._track_paths["audio"][0])
 
-    def audio(self, sample_rate=22050):
-        """
-        Load the audio for this track.
+    @property
+    def audio(self):
+        """(np.ndarray, float): audio signal, sample rate"""
+        return load_audio(self.audio_path)
 
-        Args:
-            sample_rate: Requested sample rate (optional, default 22050)
-        Returns:
-            Pair of (audio signal, actual sample rate)
-        """
-        audio, sr = librosa.load(self.audio_path, sr=sample_rate, mono=True)
-        return audio, sr
-
-    def __repr__(self):
-        return "GTZAN-Genre Track(track_id='{track_id}', genre='{genre}')".format(
-            track_id=self.track_id, genre=self.genre
+    def to_jams(self):
+        """Jams: the track's data in jams format"""
+        return jams_utils.jams_converter(
+            tags_gtzan_data=[(self.genre, 'gtzan-genre')],
+            metadata={
+                'title': "Unknown track",
+                'artist': "Unknown artist",
+                'release': "Unknown album",
+                'duration': 30.0,
+                'curator': 'George Tzanetakis',
+            },
         )
 
 
+def load_audio(audio_path):
+    """Load a GTZAN audio file.
+
+    Args:
+        audio_path (str): path to audio file
+
+    Returns:
+        y (np.ndarray): the mono audio signal
+        sr (float): The sample rate of the audio file
+
+    """
+    if not os.path.exists(audio_path):
+        raise IOError("audio_path {} does not exist".format(audio_path))
+    audio, sr = librosa.load(audio_path, sr=22050, mono=True)
+    return audio, sr
+
+
 def load(data_home=None):
     """Load GTZAN-Genre
 
@@ -133,17 +154,28 @@ def track_ids():
     return list(DATA.index.keys())
 
 
-def download(data_home=None):
+def download(data_home=None, force_overwrite=False, cleanup=True):
     """Download the GTZAN-Genre dataset.
 
     Args:
-        data_home (str): Local path where the dataset is stored.
+        data_home (str):
+            Local path where the dataset is stored.
             If `None`, looks for the data in the default directory, `~/mir_datasets`
+        force_overwrite (bool):
+            Whether to overwrite the existing downloaded data
+        cleanup (bool):
+            Whether to delete the zip/tar file after extracting.
     """
     if data_home is None:
         data_home = utils.get_default_dataset_path(DATASET_DIR)
 
-    download_utils.downloader(data_home, tar_downloads=[DATASET_REMOTE])
+    download_utils.downloader(
+        data_home,
+        remotes=REMOTES,
+        info_message=None,
+        force_overwrite=force_overwrite,
+        cleanup=cleanup,
+    )
 
 
 def cite():
