@@ -21,42 +21,33 @@ Each of these clips contains a single instrument among a taxonomy of eight:
 The Medley-solos-DB dataset is the dataset that is used in the benchmarks of
 musical instrument recognition in the publications of Lostanlen and Cella
 (ISMIR 2016) and Andén et al. (IEEE TSP 2019).
-
-Attributes:
-    DATA.index (dict): {track_id: track_data}.
-        track_id is a JSON data loaded from 'index/'
-
-    DATASET_DIR (str): The directory name for Medley-solos-DB.
-        Set to `'Medley-solos-DB'`.
-
-    DATA.metadata (dict): The metadata of Medley-solos-DB.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 import csv
 import librosa
 import logging
 import os
 
-import mirdata.utils as utils
-import mirdata.download_utils as download_utils
-import mirdata.jams_utils as jams_utils
+from mirdata import download_utils
+from mirdata import jams_utils
+from mirdata import track
+from mirdata import utils
 
 DATASET_DIR = "Medley-solos-DB"
-ANNOTATION_REMOTE = download_utils.RemoteFileMetadata(
-    filename="Medley-solos-DB_metadata.csv",
-    url="https://zenodo.org/record/3464194/files/Medley-solos-DB_metadata.csv?download=1",
-    checksum="fda6a589c56785f2195c9227809c521a",
-    destination_dir="annotation",
-)
-AUDIO_REMOTE = download_utils.RemoteFileMetadata(
-    filename="Medley-solos-DB.tar.gz",
-    url="https://zenodo.org/record/3464194/files/Medley-solos-DB.tar.gz?download=1",
-    checksum="f5facf398793ef5c1f80c013afdf3e5f",
-    destination_dir="audio",
-)
+REMOTES = {
+    'annotations': download_utils.RemoteFileMetadata(
+        filename="Medley-solos-DB_metadata.csv",
+        url="https://zenodo.org/record/3464194/files/Medley-solos-DB_metadata.csv?download=1",
+        checksum="fda6a589c56785f2195c9227809c521a",
+        destination_dir="annotation",
+    ),
+    'audio': download_utils.RemoteFileMetadata(
+        filename="Medley-solos-DB.tar.gz",
+        url="https://zenodo.org/record/3464194/files/Medley-solos-DB.tar.gz?download=1",
+        checksum="f5facf398793ef5c1f80c013afdf3e5f",
+        destination_dir="audio",
+    ),
+}
 
 
 def _load_metadata(data_home):
@@ -89,19 +80,22 @@ def _load_metadata(data_home):
 DATA = utils.LargeData("medley_solos_db_index.json", _load_metadata)
 
 
-class Track(object):
-    """Medley-solos-DB track class
+class Track(track.Track):
+    """medley_solos_db Track class
 
     Args:
         track_id (str): track id of the track
-        data_home (str): Local path where the dataset is stored.
+        data_home (str): Local path where the dataset is stored. default=None
             If `None`, looks for the data in the default directory, `~/mir_datasets`
 
     Attributes:
+        audio_path (str): path to the track's audio file
         instrument (str): instrument encoded by its English name
         instrument_id (int): instrument encoded as an integer
         song_id (int): song encoded as an integer
         subset (str): either equal to 'train', 'validation', or 'test'
+        track_id (str): track id
+
     """
 
     def __init__(self, track_id, data_home=None):
@@ -136,38 +130,64 @@ class Track(object):
         self.song_id = self._track_metadata["song_id"]
         self.subset = self._track_metadata["subset"]
 
-    def __repr__(self):
-        repr_string = (
-            "Medley-solos-DB Track(track_id={}, audio_path={}, "
-            + "instrument={}, song_id={}, subset={})"
-        )
-        return repr_string.format(
-            self.track_id, self.audio_path, self.instrument, self.song_id, self.subset
-        )
-
     @property
     def audio(self):
-        return librosa.load(self.audio_path, sr=22050, mono=True)
+        """(np.ndarray, float): audio signal, sample rate"""
+        return load_audio(self.audio_path)
 
     def to_jams(self):
-        return jams_utils.jams_converter(metadata=self._track_metadata)
+        """Jams: the track's data in jams format"""
+        return jams_utils.jams_converter(
+            audio_path=self.audio_path, metadata=self._track_metadata
+        )
 
 
-def download(data_home=None):
+def load_audio(audio_path):
+    """Load a Medley Solos DB audio file.
+
+    Args:
+        audio_path (str): path to audio file
+
+    Returns:
+        y (np.ndarray): the mono audio signal
+        sr (float): The sample rate of the audio file
+
+    """
+    if not os.path.exists(audio_path):
+        raise IOError("audio_path {} does not exist".format(audio_path))
+
+    return librosa.load(audio_path, sr=22050, mono=True)
+
+
+def download(
+    data_home=None, partial_download=None, force_overwrite=False, cleanup=True
+):
     """Download Medley-solos-DB.
 
     Args:
-        data_home (str): Local path where the dataset is stored.
+        data_home (str):
+            Local path where the dataset is stored.
             If `None`, looks for the data in the default directory, `~/mir_datasets`
+        force_overwrite (bool):
+            Whether to overwrite the existing downloaded data
+        partial_download (list):
+            List indicating what to partially download. The list can include any of:
+                * `'annotations'` the annotation files
+                * `'audio'` the audio files
+            If `None`, all data is downloaded.
+        cleanup (bool):
+            Whether to delete the zip/tar file after extracting.
     """
     if data_home is None:
         data_home = utils.get_default_dataset_path(DATASET_DIR)
 
     download_utils.downloader(
         data_home,
-        tar_downloads=[AUDIO_REMOTE],
-        file_downloads=[ANNOTATION_REMOTE],
-        cleanup=True,
+        remotes=REMOTES,
+        partial_download=partial_download,
+        info_message=None,
+        force_overwrite=force_overwrite,
+        cleanup=cleanup,
     )
 
 
