@@ -1,10 +1,13 @@
 # -*- coding: utf-8 -*-
 """RWC Popular Dataset Loader
 
-Attributes:
-    METADATA_REMOTE (RemoteFileMetadata): Metadata of the remote file
-    DATASET_DIR (str): The directory name for iKala dataset. Set to `'RWC-Pop'`.
+The Popular Music Database consists of 100 songs — 20 songs with English lyrics
+performed in the style of popular music typical of songs on the American hit
+charts in the 1980s, and 80 songs with Japanese lyrics performed in the style of
+modern Japanese popular music typical of songs on the Japanese hit charts in
+the 1990s.
 
+For more details, please visit: https://staff.aist.go.jp/m.goto/RWC-MDB/rwc-mdb-p.html
 """
 import csv
 import librosa
@@ -12,44 +15,53 @@ import logging
 import numpy as np
 import os
 
-import mirdata.utils as utils
-import mirdata.download_utils as download_utils
-import mirdata.jams_utils as jams_utils
+from mirdata import download_utils
+from mirdata import jams_utils
+from mirdata import track
+from mirdata import utils
 
 # these functions are identical for all rwc datasets
-from mirdata.rwc_classical import _load_beats, _load_sections, _duration_to_sec
+from mirdata.rwc_classical import (
+    load_beats,
+    load_sections,
+    load_audio,
+    _duration_to_sec,
+)
+
+REMOTES = {
+    'metadata': download_utils.RemoteFileMetadata(
+        filename='rwc-p.csv',
+        url='https://github.com/magdalenafuentes/metadata/archive/master.zip',
+        checksum='7dbe87fedbaaa1f348625a2af1d78030',
+        destination_dir=None,
+    ),
+    'annotations_beat': download_utils.RemoteFileMetadata(
+        filename='AIST.RWC-MDB-P-2001.BEAT.zip',
+        url='https://staff.aist.go.jp/m.goto/RWC-MDB/AIST-Annotation/AIST.RWC-MDB-P-2001.BEAT.zip',
+        checksum='3858aa989535bd7196b3cd07b512b5b6',
+        destination_dir='annotations',
+    ),
+    'annotations_sections': download_utils.RemoteFileMetadata(
+        filename='AIST.RWC-MDB-P-2001.CHORUS.zip',
+        url='https://staff.aist.go.jp/m.goto/RWC-MDB/AIST-Annotation/AIST.RWC-MDB-P-2001.CHORUS.zip',
+        checksum='f76b3a32701fbd9bf78baa608f692a77',
+        destination_dir='annotations',
+    ),
+    'annotations_chords': download_utils.RemoteFileMetadata(
+        filename='AIST.RWC-MDB-P-2001.CHORD.zip',
+        url='https://staff.aist.go.jp/m.goto/RWC-MDB/AIST-Annotation/AIST.RWC-MDB-P-2001.CHORD.zip',
+        checksum='68379c88bc8ec3f1907b32a3579197c5',
+        destination_dir='annotations',
+    ),
+    'annotations_vocal_act': download_utils.RemoteFileMetadata(
+        filename='AIST.RWC-MDB-P-2001.VOCA_INST.zip',
+        url='https://staff.aist.go.jp/m.goto/RWC-MDB/AIST-Annotation/AIST.RWC-MDB-P-2001.VOCA_INST.zip',
+        checksum='47ded648a496407ef49dba9c8bf80e87',
+        destination_dir='annotations',
+    ),
+}
 
-METADATA_REMOTE = download_utils.RemoteFileMetadata(
-    filename='rwc-p.csv',
-    url='https://github.com/magdalenafuentes/metadata/archive/master.zip',
-    checksum='7dbe87fedbaaa1f348625a2af1d78030',
-    destination_dir=None,
-)
 DATASET_DIR = 'RWC-Popular'
-ANNOTATIONS_REMOTE_1 = download_utils.RemoteFileMetadata(
-    filename='AIST.RWC-MDB-P-2001.BEAT.zip',
-    url='https://staff.aist.go.jp/m.goto/RWC-MDB/AIST-Annotation/AIST.RWC-MDB-P-2001.BEAT.zip',
-    checksum='3858aa989535bd7196b3cd07b512b5b6',
-    destination_dir='annotations',
-)
-ANNOTATIONS_REMOTE_2 = download_utils.RemoteFileMetadata(
-    filename='AIST.RWC-MDB-P-2001.CHORUS.zip',
-    url='https://staff.aist.go.jp/m.goto/RWC-MDB/AIST-Annotation/AIST.RWC-MDB-P-2001.CHORUS.zip',
-    checksum='f76b3a32701fbd9bf78baa608f692a77',
-    destination_dir='annotations',
-)
-ANNOTATIONS_REMOTE_3 = download_utils.RemoteFileMetadata(
-    filename='AIST.RWC-MDB-P-2001.CHORD.zip',
-    url='https://staff.aist.go.jp/m.goto/RWC-MDB/AIST-Annotation/AIST.RWC-MDB-P-2001.CHORD.zip',
-    checksum='68379c88bc8ec3f1907b32a3579197c5',
-    destination_dir='annotations',
-)
-ANNOTATIONS_REMOTE_4 = download_utils.RemoteFileMetadata(
-    filename='AIST.RWC-MDB-P-2001.VOCA_INST.zip',
-    url='https://staff.aist.go.jp/m.goto/RWC-MDB/AIST-Annotation/AIST.RWC-MDB-P-2001.VOCA_INST.zip',
-    checksum='47ded648a496407ef49dba9c8bf80e87',
-    destination_dir='annotations',
-)
 
 
 def _load_metadata(data_home):
@@ -100,28 +112,33 @@ def _load_metadata(data_home):
 DATA = utils.LargeData('rwc_popular_index.json', _load_metadata)
 
 
-class Track(object):
-    """RWC Popular Track class
+class Track(track.Track):
+    """rwc_popular Track class
 
     Args:
-        track_id (str): Track id of the Track
-        data_home (str): Local path where the dataset is stored.
+        track_id (str): track id of the track
+        data_home (str): Local path where the dataset is stored. default=None
             If `None`, looks for the data in the default directory, `~/mir_datasets`
 
     Attributes:
-        track_id (str): Track id
-        audio_path (str): Audio path of this Track
-        piece_number (str): Piece number of this Track, [1-50]
-        suffix (str): M01-M04
-        track_number: CD track number of this Track
-        title (str): Title of The track.
-        artist (str): Artist name with the vocal's gender
-            E.g., 'Makoto Nakamura'
-        duration_sec (float): Duration of the track in seconds
-        tempo (float): Tempo of the track in BPM
-        instruments (list): List of used instruments
+        artist (str): artist
+        audio_path (str): path of the audio file
+        beats_path (str): path of the beat annotation file
+        chords_path (str): path of the chord annotation file
         drum_information (str): If the drum is 'Drum sequences', 'Live drums',
             or 'Drum loops'
+        duration (float): Duration of the track in seconds
+        instruments (str): List of used instruments
+        piece_number (str): Piece number, [1-50]
+        sections_path (str): path of the section annotation file
+        singer_information (str): TODO
+        suffix (str): M01-M04
+        tempo (str): Tempo of the track in BPM
+        title (str): title
+        track_id (str): track id
+        track_number (str): CD track number
+        voca_inst_path (str): path of the vocal/instrumental annotation file
+
     """
 
     def __init__(self, track_id, data_home=None):
@@ -137,6 +154,14 @@ class Track(object):
         self._data_home = data_home
 
         self._track_paths = DATA.index[track_id]
+        self.sections_path = os.path.join(
+            self._data_home, self._track_paths['sections'][0]
+        )
+        self.beats_path = os.path.join(self._data_home, self._track_paths['beats'][0])
+        self.chords_path = os.path.join(self._data_home, self._track_paths['chords'][0])
+        self.voca_inst_path = os.path.join(
+            self._data_home, self._track_paths['voca_inst'][0]
+        )
 
         metadata = DATA.metadata(data_home)
         if metadata is not None and track_id in metadata:
@@ -169,60 +194,35 @@ class Track(object):
         self.instruments = self._track_metadata['instruments']
         self.drum_information = self._track_metadata['drum_information']
 
-    def __repr__(self):
-        repr_string = (
-            "RWC-Popular Track(track_id={}, audio_path={}, "
-            + "piece_number={}, suffix={}, track_number={}, title={}, "
-            + "artist={}, singer_information={}, duration={}, "
-            + "tempo={}, instruments={}, drum_information={}, "
-            + "sections=SectionData('intervals', 'labels'), "
-            + "beats=BeatData('beat_times', 'beat_positions'))"
-            + "chords=ChordData('intervals', 'labels'), "
-            + "vocal_instrument_activity=EventData('start_times', 'end_times', 'event')"
-        )
-        return repr_string.format(
-            self.track_id,
-            self.audio_path,
-            self.piece_number,
-            self.suffix,
-            self.track_number,
-            self.title,
-            self.artist,
-            self.singer_information,
-            self.duration,
-            self.tempo,
-            self.instruments,
-            self.drum_information,
-        )
-
     @utils.cached_property
     def sections(self):
-        return _load_sections(
-            os.path.join(self._data_home, self._track_paths['sections'][0])
-        )
+        """SectionData: human-labeled section annotation"""
+        return load_sections(self.sections_path)
 
     @utils.cached_property
     def beats(self):
-        return _load_beats(os.path.join(self._data_home, self._track_paths['beats'][0]))
+        """BeatData: human-labeled beat annotation"""
+        return load_beats(self.beats_path)
 
     @utils.cached_property
     def chords(self):
-        return _load_chords(
-            os.path.join(self._data_home, self._track_paths['chords'][0])
-        )
+        """ChordData: human-labeled chord annotation"""
+        return load_chords(self.chords_path)
 
     @utils.cached_property
     def vocal_instrument_activity(self):
-        return _load_voca_inst(
-            os.path.join(self._data_home, self._track_paths['voca_inst'][0])
-        )
+        """EventData: human-labeled vocal/instrument activity"""
+        return load_voca_inst(self.voca_inst_path)
 
     @property
     def audio(self):
-        return librosa.load(self.audio_path, sr=None, mono=True)
+        """(np.ndarray, float): audio signal, sample rate"""
+        return load_audio(self.audio_path)
 
     def to_jams(self):
+        """Jams: the track's data in jams format"""
         return jams_utils.jams_converter(
+            audio_path=self.audio_path,
             beat_data=[(self.beats, None)],
             section_data=[(self.sections, None)],
             chord_data=[(self.chords, None)],
@@ -230,7 +230,30 @@ class Track(object):
         )
 
 
-def download(data_home=None, force_overwrite=False):
+def download(
+    data_home=None, partial_download=None, force_overwrite=False, cleanup=True
+):
+    """Download the RWC Popular (annotations and metadata).
+    The audio files are not provided due to copyright issues.
+
+    Args:
+        data_home (str):
+            Local path where the dataset is stored.
+            If `None`, looks for the data in the default directory, `~/mir_datasets`
+        force_overwrite (bool):
+            Whether to overwrite the existing downloaded data
+        partial_download (list):
+             List indicating what to partially download. The list can include any of:
+             * `'annotations_beat'` the beat annotation files
+             * `'annotations_sections'` the sections annotation files
+             * `'annotations_chords'` the chords annotation files
+             * `'annotations_vocal_act'` the vocal activity annotation files
+             * `'metadata'` the metadata files
+             If `None`, all data is downloaded.
+        cleanup (bool):
+            Whether to delete the zip/tar file after extracting.
+
+    """
 
     if data_home is None:
         data_home = utils.get_default_dataset_path(DATASET_DIR)
@@ -250,15 +273,11 @@ def download(data_home=None, force_overwrite=False):
 
     download_utils.downloader(
         data_home,
-        zip_downloads=[
-            METADATA_REMOTE,
-            ANNOTATIONS_REMOTE_1,
-            ANNOTATIONS_REMOTE_2,
-            ANNOTATIONS_REMOTE_3,
-            ANNOTATIONS_REMOTE_4,
-        ],
+        remotes=REMOTES,
+        partial_download=partial_download,
         info_message=info_message,
         force_overwrite=force_overwrite,
+        cleanup=cleanup,
     )
 
 
@@ -314,9 +333,10 @@ def load(data_home=None):
     return rwc_popular_data
 
 
-def _load_chords(chords_path):
+def load_chords(chords_path):
     if not os.path.exists(chords_path):
-        return None
+        raise IOError("chords_path {} does not exist".format(chords_path))
+
     begs = []  # timestamps of chord beginnings
     ends = []  # timestamps of chord endings
     chords = []  # chord labels
@@ -332,9 +352,10 @@ def _load_chords(chords_path):
     return utils.ChordData(np.array([begs, ends]).T, chords)
 
 
-def _load_voca_inst(voca_inst_path):
+def load_voca_inst(voca_inst_path):
     if not os.path.exists(voca_inst_path):
-        return None
+        raise IOError("voca_inst_path {} does not exist".format(voca_inst_path))
+
     begs = []  # timestamps of vocal-instrument activity beginnings
     ends = []  # timestamps of vocal-instrument activity endings
     events = []  # vocal-instrument activity labels
