@@ -4,7 +4,7 @@
 Attributes:
     MIR_DATASETS_DIR (str): home folder for MIR datasets
 
-    NoteData (namedtuple): `start_times`, `end_times`, `notes`, `confidence`
+    NoteData (namedtuple): `intervals`, `notes`, `confidence`
 
     F0Data (namedtuple): `times`, `frequencies`, `confidence`
 
@@ -20,10 +20,10 @@ Attributes:
 
     EventData (namedtuple): `start_times`, `end_times`, `event`
 
+    TempoData (namedtuple): `time`, `duration`, `value`, `confidence`
+
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+
 
 from collections import namedtuple
 import hashlib
@@ -51,6 +51,23 @@ def md5(file_path):
     return hash_md5.hexdigest()
 
 
+def none_path_join(partial_path_list):
+    """Join a list of partial paths. If any part of the path is None,
+    returns None.
+
+    Args:
+        partial_path_list (list): List of partial paths
+
+    Returns:
+        path or None (str or None): joined path string or None
+
+    """
+    if None in partial_path_list:
+        return None
+    else:
+        return os.path.join(*partial_path_list)
+
+
 def log_message(message, silence=False):
     """Helper function to log message
 
@@ -142,16 +159,22 @@ def validator(dataset_index, data_home, silence=False):
             has_any_invalid_checksum = True
 
     if not (has_any_missing_file or has_any_invalid_checksum):
-        log_message('Success: the dataset is complete and all files are valid.', silence)
+        log_message(
+            'Success: the dataset is complete and all files are valid.', silence
+        )
         log_message('-' * 20, silence)
 
     return missing_files, invalid_checksums
 
 
-NoteData = namedtuple('NoteData', ['start_times', 'end_times', 'notes', 'confidence'])
+NoteData = namedtuple('NoteData', ['intervals', 'notes', 'confidence'])
 
 F0Data = namedtuple('F0Data', ['times', 'frequencies', 'confidence'])
 
+MultipitchData = namedtuple(
+    'MultipitchData', ['times', 'frequency_list', 'confidence_list']
+)
+
 LyricData = namedtuple(
     'LyricData', ['start_times', 'end_times', 'lyrics', 'pronunciations']
 )
@@ -164,6 +187,8 @@ ChordData = namedtuple('ChordData', ['intervals', 'labels'])
 
 KeyData = namedtuple('KeyData', ['start_times', 'end_times', 'keys'])
 
+TempoData = namedtuple('TempoData', ['time', 'duration', 'value', 'confidence'])
+
 EventData = namedtuple('EventData', ['start_times', 'end_times', 'event'])
 
 
@@ -187,10 +212,10 @@ def load_json_index(filename):
 
 
 class cached_property(object):
-    """ A property that is only computed once per instance and then replaces
-        itself with an ordinary attribute. Deleting the attribute resets the
-        property.
-        Source: https://github.com/bottlepy/bottle/commit/fa7733e075da0d790d809aa3d2f53071897e6f76
+    """A property that is only computed once per instance and then replaces
+    itself with an ordinary attribute. Deleting the attribute resets the
+    property.
+    Source: https://github.com/bottlepy/bottle/commit/fa7733e075da0d790d809aa3d2f53071897e6f76
     """
 
     def __init__(self, func):
